/*
   EASY LASER GUN BY ARNAUD ATCHIMON @NEOFUTURISM.NET
   DO NOT SHOOT YOUR EYES OUT!! PLEASE :)
   TUNES: Thanks to Robson Couto for his mario tune
   https://github.com/robsoncouto/arduino-songs/blob/master/supermariobros/supermariobros.ino
   Super Mario Bros theme
   Score available at https://musescore.com/user/2123/scores/2145
   Theme by Koji Kondo

   CONNECTION
   ----------
   NANO
   PIN 10 // BUTTON PIN
   PIN 5  // LASER PIN
   PIN 8  // PIEZO PIN
   CONNECT 9V CONNECTOR TO [ (+) TO VIN ] - [ (-) TO GND ]
*/

#include "GUN_PITCHES.h"

const int laserPin = 5;     // LASER PIN
const int audioPin = 8;     // PIEZO PIN
const int buttonPin = 10;   //W  TRIGGER PIN
const int onboardLed = 13;  // ONBOARD LED

//TUNES MARIO/DOOM
int tempo = 200; //MUSIC SPEED
int marioNotes = sizeof(MARIO_TONE) / sizeof(MARIO_TONE[0]) / 2;
int dooomnotes = sizeof(DOOM_TONE) / sizeof(DOOM_TONE[0]) / 2;
int whole_note = (60000 * 4) / tempo;
int divider = 0, noteDuration = 0;

//GUN SETTINGS
bool bulletMode = false;
int bulletNumber = 10; // CHANGE THIS IF YOU WANT MORE BULLETS
int gunReload = 0;
int bulletReload = bulletNumber;

void setup() {
  Serial.begin(115200);
  pinMode(buttonPin, INPUT_PULLUP);
  pinMode(onboardLed, OUTPUT);
  pinMode(laserPin, OUTPUT);
  digitalWrite(laserPin, LOW);
  digitalWrite(buttonPin, HIGH);

  //  IF TRIGGER PRESSED FULLY AUTOMATIC SHOOTING
  //  IF NOT # BULLET IS NUMBER IN YOUR CLIP
  if (digitalRead(buttonPin) == LOW) {
    bulletMode = true;
    START_TUNE(DOOM_TONE,  dooomnotes ); //PLAY DOOM TUNE
  } else {
    START_TUNE(MARIO_TONE, marioNotes ); //PLAY MARIO TUNE
  }

}


void loop() {
  int btnReads = digitalRead(buttonPin);
  Serial.println("BUTTON READ: " + String(btnReads) );
  Serial.println("BULLETS " + String(gunReload) );
  
  //READ BUTTON
  if (btnReads == LOW) {
    digitalWrite(onboardLed, LOW);
    tone(audioPin, PEWPEW_TUNE[0], 100);
    gunReload++;
    digitalWrite(laserPin, HIGH);
    delay(200);
  } else {
    digitalWrite(laserPin, LOW);
    digitalWrite(onboardLed, HIGH);
    noTone(audioPin);
  }

  // CHECK IF SINGLE OR FULL AUTOMATIC MODE
  if (bulletMode == false) {
    if (gunReload >= bulletNumber) {
      digitalWrite(laserPin, LOW);
      for (int i = 0; i <= bulletReload; i++) {
        i++;
        tone(audioPin, PEWPEW_TUNE[1], 30);
        btnReads = 1;
        digitalWrite(onboardLed, LOW);
        delay(50);
        digitalWrite(onboardLed, HIGH);
        delay(100);
        noTone(audioPin);
      }
      gunReload = 0;
      delay(100);
    }
    
  }
  
}

//PLAY MUSIC
void START_TUNE(int tune[], int notesSize) {
  for (int thisNote = 0; thisNote < notesSize * 2; thisNote = thisNote + 2) {
    divider =  tune[thisNote + 1];
    if (divider > 0) {
      noteDuration = (whole_note) / divider;
    } else if (divider < 0) {
      noteDuration = (whole_note) / abs(divider);
      noteDuration *= 1.5;
    }
    tone(audioPin, tune[thisNote], noteDuration * 0.9);
    delay(noteDuration);
    noTone(audioPin);
  }
}
